@@ -725,6 +725,7 @@ def get_package_requirements(
     status, output = getstatusoutput(
         f'{sys.executable} -m pip show {package_name}'
     )
+    required_package_names: Set[str] = set()
     for line in output.split('\n'):
         if line.startswith('Requires:'):
             required_package_name: str
@@ -738,8 +739,18 @@ def get_package_requirements(
                         for required_package_depencency_name in (
                             get_package_requirements(required_package_name)
                         ):
-                            yield required_package_depencency_name
-                    yield required_package_name
+                            if required_package_depencency_name not in (
+                                required_package_names
+                            ):
+                                yield required_package_depencency_name
+                                required_package_names.add(
+                                    required_package_depencency_name
+                                )
+                    if required_package_name not in (
+                        required_package_names
+                    ):
+                        yield required_package_name
+                        required_package_names.add(required_package_name)
             break
 
 
